Changelog for cygenja
======================

0.2.1 (unreleased)
------------------

- Nothing changed yet.


0.2.0 (unreleased)
------------------

- Added GeneratorActionContainer to store GeneratorAction;
- Use of TreeMap structure to hold GeneratorActionContainer;
- test on CySparse to generate the library with cygenja;
- changed find_files to return both directory and filename;
- completely rewrote the generation algorithm;

0.1.2 (2015-11-14)
------------------

- Still trying to use zest.releaser.

0.1.1
----------------

- Trying zset.releaser

0.1.0
----------------

- Trying to setup the setup environment.

0.0.1
----------------

- cygenja was born.

